@@ -1177,6 +1177,7 @@ static int amber_SciCal(
 	int  iLoadedFrameCount = 0;
 	int  iReduction        = 0;
 	FILE * fpTmp = NULL;
+	cpl_frameset_iterator * it = NULL;
 
 	/*int  iOnlyWriteOne     = 0;*/
 
@@ -1380,7 +1381,8 @@ static int amber_SciCal(
     for each OBJECT we will perform a calculation of visibilities and write a product
 
 	 */
-	cur_frame = cpl_frameset_get_first( framelist );
+	it = cpl_frameset_iterator_new(framelist);
+	cur_frame = cpl_frameset_iterator_get(it);
 
 	while( cur_frame )
 	{
@@ -1417,7 +1419,9 @@ static int amber_SciCal(
 
 				cpl_msg_warning(cpl_func, "Currently only %d interferometric frames can be processed",MAXFILESRAW);
 				cpl_msg_warning(cpl_func, "Scipping frame: %s", pszFilename);
-				cur_frame = cpl_frameset_get_next( framelist );
+				cpl_frameset_iterator_advance(it, 1);
+				cur_frame = cpl_frameset_iterator_get(it);
+
 				continue;
 			}
 
@@ -1461,8 +1465,11 @@ static int amber_SciCal(
 			cpl_msg_info( fctid, "%s", szMessage );
 		} /* Filename and Tag present */
 
-		cur_frame = cpl_frameset_get_next( framelist );
+		cpl_frameset_iterator_advance(it, 1);
+		cur_frame = cpl_frameset_iterator_get(it);
+
 	} /* while more frames */
+	cpl_frameset_iterator_delete(it);
 
 	/* For all existing tmp products create the real products */
 	iProductNumber = 0;
@@ -1574,7 +1581,7 @@ static void select_frames(cpl_parameterlist * parlist, cpl_frameset * framelist,
 			/*Select according to SNR*/
 			outname_selector = cpl_sprintf("snr_filtered_%s",
 					cpl_frame_get_filename(pframeSCIENCE[i]));
-			status_snr=amber_selector_lib(50, 50, 50, 1,
+			status_snr=amber_selector_lib(50, 50, 50, 1, 0,
 					"Fringe_SNR_percentage_x",
 					cpl_frame_get_filename(pframeSCIENCE[i]),
 					outname_selector, isScience,
@@ -1582,10 +1589,10 @@ static void select_frames(cpl_parameterlist * parlist, cpl_frameset * framelist,
 			if(status_snr==0)
 			{
 				frame_selector_snr[i]=cpl_frame_duplicate(
-						cpl_frameset_get_frame(local_framelist,1));
+						cpl_frameset_get_position(local_framelist,1));
 				cpl_frameset_insert(framelist,frame_selector_snr[i]);
 				cpl_frameset_erase_frame(local_framelist,
-						cpl_frameset_get_frame(local_framelist,1));
+						cpl_frameset_get_position(local_framelist,1));
 
 				/*------------------------------------------------------------*/
 				/*Derive the transfer function*/
@@ -1631,7 +1638,7 @@ static void select_frames(cpl_parameterlist * parlist, cpl_frameset * framelist,
 
 			outname_selector = cpl_sprintf("pst_filtered_%s",
 					cpl_frame_get_filename(pframeSCIENCE[i]));
-			status_pst=amber_selector_lib(x1_pst, x2_pst, x3_pst, 1,
+			status_pst=amber_selector_lib(x1_pst, x2_pst, x3_pst, 1, 0,
 					"Absolute_piston_value_lt_x",
 					cpl_frame_get_filename(pframeSCIENCE[i]),
 					outname_selector, isScience,
@@ -1639,10 +1646,10 @@ static void select_frames(cpl_parameterlist * parlist, cpl_frameset * framelist,
 			if(status_pst==0)
 			{
 				frame_selector_pst[i]=cpl_frame_duplicate(
-						cpl_frameset_get_frame(local_framelist,1));
+						cpl_frameset_get_position(local_framelist,1));
 				cpl_frameset_insert(framelist,frame_selector_pst[i]);
 				cpl_frameset_erase_frame(local_framelist,
-						cpl_frameset_get_frame(local_framelist,1));
+						cpl_frameset_get_position(local_framelist,1));
 
 				/*------------------------------------------------------------*/
 				/*Derive the transfer function*/
