@@ -426,7 +426,7 @@ static int amber_detector(
 	int  iFrameCountDark   = 0;
 	int  iFrameCountFlat   = 0;
 
-
+	cpl_frameset_iterator * it = NULL;
 
 	int  i                 = 0;
 
@@ -494,11 +494,11 @@ static int amber_detector(
     Walk through the whole Set of Frames SOF and search for DETECTOR_FFM and DETECTOR_DARK
     Seven of each are needed
 	 */
-	cur_frame = cpl_frameset_get_first( framelist );
+
+	it = cpl_frameset_iterator_new(framelist);
 
 
-
-	while( cur_frame )
+	while((cur_frame = cpl_frameset_iterator_get(it)))
 	{
 		/* Get Filename and Classification Tag */
 		pszFilename = (char *)cpl_frame_get_filename( cur_frame );
@@ -532,9 +532,10 @@ static int amber_detector(
 		}
 
 		/* Get next frame from SOF */
-		cur_frame = cpl_frameset_get_next( framelist );
+		cpl_frameset_iterator_advance(it, 1);
 
 	} /* while more frames */
+	cpl_frameset_iterator_delete(it);
 
 	if( iFrameCountFlat!=7 || iFrameCountDark!=7 )
 	{
