@@ -177,6 +177,7 @@ static cpl_error_code amber_propertylist_append(cpl_propertylist * self,
 		case CPL_TYPE_CHAR:
 			err = cpl_propertylist_append_char(self, name,
 					cpl_property_get_char(prop));
+			break;
 		case CPL_TYPE_BOOL:
 			err = cpl_propertylist_append_bool(self, name,
 					cpl_property_get_bool(prop));
@@ -1105,7 +1106,7 @@ static int amber_p2vm(
 	/* CPL structures */
 	cpl_frameset * cur_set;
 	cpl_frame    * cur_frame;
-
+	cpl_frameset_iterator * it = NULL;
 	/*	FILE         * fpWave;*/
 	long zeroframes = 0;
 	char   szMessage[1024];
@@ -1276,7 +1277,8 @@ static int amber_p2vm(
 			"(current status = %d)", iStatus );
 	cpl_msg_info( fctid, "%s", szMessage );
 
-	cur_frame = cpl_frameset_get_first( framelist );
+	it = cpl_frameset_iterator_new(framelist);
+	cur_frame = cpl_frameset_iterator_get(it);
 
 	while( cur_frame && !iStatus )
 	{
@@ -1316,7 +1318,8 @@ static int amber_p2vm(
 		}
 
 		/* Proceed with next frame */
-		cur_frame = cpl_frameset_get_next( framelist );
+		  cpl_frameset_iterator_advance(it, 1);
+		  cur_frame = cpl_frameset_iterator_get(it);
 	} /* while more frames */
 
 
@@ -1409,7 +1412,9 @@ static int amber_p2vm(
 
 	i3TelFrames = 0;
 	i2TelFrames = 0;
-	cur_frame = cpl_frameset_get_first( framelist );
+
+	cpl_frameset_iterator_reset(it);
+	cur_frame = cpl_frameset_iterator_get(it);
 
 	while( cur_frame )
 	{
@@ -1447,8 +1452,11 @@ static int amber_p2vm(
 		}
 
 		/* Proceed with next frame */
-		cur_frame = cpl_frameset_get_next( framelist );
+		cpl_frameset_iterator_advance(it, 1);
+		cur_frame = cpl_frameset_iterator_get(it);
+
 	} /* while more frames */
+	cpl_frameset_iterator_delete(it);
 
 	/* Test Number of Frames and call Data Reduction */
 	if( strlen(szFilenameBadPix) && strlen(szFilenameFlat) )
@@ -1735,7 +1743,7 @@ static long amber_check_zeroframes(cpl_parameterlist * parlist,
 
 	/* Loop on the frames and test for zeroframes */
 	for (i=0 ; i<nbframes ; i++) {
-		cur_frame = cpl_frameset_get_frame_const(framelist, i) ;
+		cur_frame = cpl_frameset_get_position_const(framelist, i) ;
 
 		if (!strcmp(cpl_frame_get_tag(cur_frame), "AMBER_3P2V") ||
 				!strcmp(cpl_frame_get_tag(cur_frame), "AMBER_2P2V"))
